# NetFEMA Bootstrap Assets

This repository contains the assets for the NetFEMA Bootstrap theme. The theme is based on the [Bootstrap](http://getbootstrap.com/) framework.

Base Bootstrap Toolkit: Version 5.3.0
Bootstrap Icons: Version 1.10.5
